pub unsafe extern "system" fn breakpoint_handler(
exceptioninfo: *mut ExceptionPointers,
) -> i32Available on x86-64 only.
This function acts as an Exception Handler, and should be combined with a hardware breakpoint.
Whenever the HB gets triggered, this function will be executed. This is meant to be used in order to spoof syscalls parameters.