pub fn get_module_base_address(module_name: &str) -> usizeExpand description
Retrieves the base address of a module loaded in the current process.
In case that the module can’t be found in the current process, it will return 0.
Examples
let ntdll = dyncvoke_core::get_module_base_address("ntdll.dll");
if ntdll != 0
{
println!("The base address of ntdll.dll is 0x{:X}.", ntdll);
}